==> ping_stat-0.1.0.tar.gz: ping_stat-0.1.0/ping_stat/__about__.py <==
"""
Project: PingPing
Author: Inspyre Softworks - https://inspyre.techCreated: 2/23/2023 @ 9:09 AM
File:
  Name: __about__
  Filepath: ping_stat
"""

__PROG__ = 'PingPing'

__DESCRIPTION__ = f'{__PROG__} is a simple ping-time monitoring service that can assist in monitoring for and ' \
                  f'documenting outages from your ISP.'

__VERSION__ = '0.1.0_dev1'

__VERSION_FULL__ = f'{__PROG__} v{__VERSION__}'





"""
The MIT License (MIT)
Copyright © 2023 Inspyre Softworks - https://inspyre.tech
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."""

==> ping_stat-1.0.tar.gz: ping_stat-1.0/ping_stat/__about__.py <==
"""
Project: PingPing
Author: Inspyre Softworks - https://inspyre.techCreated: 2/23/2023 @ 9:09 AM
File:
  Name: __about__
  Filepath: ping_stat
"""

__AUTHOR__ = 'Inspyre Softworks'

__PROG__ = 'PingPing'

__DESCRIPTION__ = f'{__PROG__} is a simple ping-time monitoring service that can assist in monitoring for and ' \
                  f'documenting outages from your ISP.'

__VERSION__ = '1.0'

__VERSION_FULL__ = f'{__PROG__} v{__VERSION__} by {__AUTHOR__}'





"""
The MIT License (MIT)
Copyright © 2023 Inspyre Softworks - https://inspyre.tech
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."""
